/* Workspace Switcher */

@use "../../../../theme";
@use "../../../../theme-color";
@use "osd";

.workspace-switcher-group {
  padding: 8px;
}

.workspace-switcher-container {
  @include osd.panel;
}

.workspace-switcher {
  background: transparent;
  border: 0;
  border-radius: 0;
  padding: 0;
  spacing: 8px;
}

.ws-switcher-box {
  height: 48px;
  border: 0;
  border-radius: theme.$corner-radius;
  background-color: theme-color.disabled-stroke(theme-color.$on-surface);
  background-size: 0;
}

// active workspace in the switcher
.ws-switcher-active-up,
.ws-switcher-active-down,
.ws-switcher-active-left,
.ws-switcher-active-right {
  height: 48px;
  border: 0;
  border-radius: theme.$corner-radius;
  background-color: theme-color.$primary;
  background-size: 0;
  color: inherit;
}
