$variant: 'light';
$titlebar: 'dark';

@import '../../_sass/colors';
@import '../../_sass/variables';
@import '../../_sass/gtk/drawing';
@import '../../_sass/gtk/common-3.0';
@import '../../_sass/gtk/apps-3.0';
@import '../../_sass/gtk/granite';
@import '../../_sass/gtk/darksidebar_widgets';
@import '../../_sass/gtk/colors-public';
