/**
 * LightDM GTK+ Greeter
 */

// Based on:
// https://bazaar.launchpad.net/~lightdm-gtk-greeter-team/lightdm-gtk-greeter/trunk/view/head:/data/sample-lightdm-gtk-greeter.css

@use "../../../theme";
@use "../../../theme-color";
@use "../../../shadow";
@use "../common";
@use "../drawing";

// the panel widget at the top
#panel_window {
  background-color: theme-color.$scrim-alt;
  color: theme-color.$on-scrim-alt;
  // font-weight: bold;

  // the menubars/menus of the panel, i.e. indicators
  menubar,
  separator {
    background-color: transparent;
  }

  separator {
    padding: 0 4px;

    &:first-child {
      padding: 0 8px;
    }
  }

  menubar > menuitem {
    color: theme-color.hint(theme-color.$on-scrim-alt);

    &:hover {
      background-color: theme-color.activated-overlay(theme-color.$on-scrim-alt);
      color: theme-color.$on-scrim-alt;
    }

    &:disabled {
      color: theme-color.disabled-hint(theme-color.$on-scrim-alt);
    }
  }
}

// the login window
#login_window,
#shutdown_dialog,
#restart_dialog {
  margin: 8px;
  border-radius: theme.$corner-radius;
  box-shadow: shadow.$z6, inset 0 1px theme-color.highlight(theme-color.$surface-z8);
  background-color: theme-color.$surface-z8;
  color: theme-color.$on-surface;
}

// the top half of the login-window, in GtkDialog terms, the content
#content_frame {
  padding-bottom: 28px - 12px; // take into account the hard-coded 12px margin_bottom
}

#login_window {
  // the user-combobox
  #user_combobox button {
  }

  // the entries, one for the username, one for the password
  entry {
  }
}

// the buttons, alternatively this could also be done with a simple ".lightdm-gtk-greeter button"
#login_window button,
#shutdown_dialog button,
#restart_dialog button {
}

.lightdm-gtk-greeter button {
}

// the user's avatar box
#user_image {
}

// the border around the user's avatar box
#user_image_border {
}

// the lower half of the login-window, in GtkDialog terms the buttonbox or action area
#buttonbox_frame {
  padding-top: 24px;

  > box,
  > buttonbox {
    margin: -16px;
  }

  button {
    @extend %button-flat;

    &:not(:disabled) {
      color: theme-color.$primary;
      @include drawing.ink-color(theme-color.$primary, $button-style: "flat");
    }
  }
}

// the shutdown button
#shutdown_button {
}

// the restart button
#restart_button {
}

// the warning, in case a wrong password is entered or something else goes wrong according to PAM
#greeter_infobar {
  // font-weight: bold;
}
