/* Slider */

.slider {
  color: $selected_bg_color;

  -slider-handle-radius: 7px;
  // barlevels are for >= 3.29.90
  -barlevel-height: 2px;
  -barlevel-background-color: $button_border;
  -barlevel-active-background-color: $selected_bg_color;
  -barlevel-overdrive-color: $destructive_color;
  -barlevel-overdrive-separator-width: 2px;

  &:hover {
    color: lighten($selected_bg_color, 7%);
  }
}
