/* Activities Ripple */

@use "../../../../theme-color";

.ripple-box {
  width: 48px;
  height: 48px;
  border-radius: 0 0 48px 0; // radius equals the size of the box to give us the curve
  box-shadow: none;
  background-color: theme-color.stroke(theme-color.$on-dark);
  background-image: none;
  background-size: auto;

  // just a simple change to the border radius position
  &:rtl {
    border-radius: 0 0 0 48px;
    background-image: none;
  }
}
