/* Looking Glass */

@use "../../../../theme";
@use "../../../../theme-color";
@use "../../../../shadow";
@use "../../gnome-shell";
@use "../../typography";
@use "../base/button";
@use "../base/entry";

// Dialog
#LookingGlassDialog {
  spacing: 0;
  padding: 0;
  border: 0;
  border-radius: theme.$corner-radius;
  box-shadow: shadow.$z8;
  background-color: theme-color.$surface-z8;
  color: theme-color.$on-surface;

  & > #Toolbar {
    padding: 0 8px;
    border: 0;
    border-radius: 0;
    box-shadow: inset 0 -1px theme-color.divider(theme-color.$on-surface);
    background-color: rgba(theme-color.$surface-z8, .01);
  }

  .labels {
    spacing: 0;
  }

  .notebook-tab {
    -natural-hpadding: 12px;
    -minimum-hpadding: 6px;
    transition-duration: theme.$state-duration;
    min-height: theme.$medium-size;
    padding-left: 16px * 2;
    padding-right: 16px * 2;
    border: 0;
    color: theme-color.hint(theme-color.$on-surface);
    font-weight: bold;

    &:hover {
      background-color: theme-color.hover-overlay(theme-color.$on-surface);
      color: theme-color.hint(theme-color.$on-surface);
      text-shadow: none;
    }

    &:active {
      transition-duration: theme.$ripple-duration;
      background-color: theme-color.pressed-overlay(theme-color.$on-surface);
    }

    &:selected {
      border: 0;
      box-shadow: inset 0 -2px theme-color.$primary;
      background-color: rgba(theme-color.$surface-z8, .01);
      color: theme-color.$on-surface;
      text-shadow: none;
    }
  }

  StBoxLayout#EvalBox {
    padding: 8px;
    spacing: 4px;
  }

  StBoxLayout#ResultsArea {
    spacing: 4px;
  }
}

.lg-dialog {
  StEntry {
    @extend %entry;
  }

  .shell-link {
    &,
    &:hover,
    &:active {
      color: theme-color.$primary;
    }
  }

  @if gnome-shell.$version >= 3.38 {
    .actor-link {
      &,
      &:hover,
      &:active {
        color: inherit;
      }
    }
  }
}

.lg-completions-text {
  font-size: 1em;
  font-style: italic;
}

.lg-obj-inspector-title {
  spacing: 4px;
}

.lg-obj-inspector-button {
  @extend %button;

  &,
  &:hover {
    border: 0;
  }
}

// Windows
#Windows {
  padding: 8px;
}

// Extensions
#lookingGlassExtensions {
  padding: 8px;
}

.lg-extensions-list {
  padding: 0;
  spacing: 6px;
}

.lg-extension {
  padding: 4px;
  border: 0;
  border-radius: 0;
  background-color: transparent;
}

.lg-extension-name {
  @include typography.headline6;
}

.lg-extension-meta {
  spacing: 6px;
}

// Inspector
#LookingGlassPropertyInspector {
  padding: 6px;
  border: 0;
  border-radius: theme.$corner-radius;
  box-shadow: shadow.$z8;
  background-color: theme-color.$surface-z8;
  color: theme-color.$on-surface;
}
